@@ -118,14 +118,14 @@ class RemoteFileField(TextField):
             self.data = valuelist[0]
 
     def process_data(self, value):
-        print value
         TextField.__init__(self, value)
 
     def populate_obj(self, obj, name):
         if getattr(obj, name) is None:
             newfile = getattr(obj.__class__, name).mapper.class_()
             setattr(obj, name, newfile)
-        getattr(obj, name).set_path(self.data)
+            if self.raw_data and len(self.raw_data):
+                getattr(obj, name).set_path(self.raw_data[0])
 
 
 class PictureWidget(RenderTemplateWidget):
@@ -147,7 +147,8 @@ class PictureField(TextField):
         if getattr(obj, name) is None:
             newfile = getattr(obj.__class__, name).mapper.class_()
             setattr(obj, name, newfile)
-        #getattr(obj, name).set_path(self.data['path'])
+            if self.raw_data and len(self.raw_data):
+                getattr(obj, name).set_path(self.raw_data[0])
 
     def process_formdata(self, valuelist):
         if self.data:
